@@ -3,6 +3,7 @@ use cosmwasm_std::entry_point;
 use cosmwasm_std::{
     to_binary, Binary, Deps, DepsMut, Env, MessageInfo, Response, StdResult, Uint128,
 };
+use cw20_base::enumerable::{query_all_allowances, query_all_accounts};
 
 use crate::error::ContractError;
 use crate::msg::{ExecuteMsg, InstantiateMsg, MigrateMsg, QueryMsg};
@@ -14,7 +15,7 @@ use cw20_base::allowances::{
 };
 use cw20_base::contract::{
     execute_burn, execute_mint, execute_send, execute_transfer, execute_update_marketing,
-    execute_upload_logo, query_balance, query_token_info,
+    execute_upload_logo, query_balance, query_token_info, query_minter, query_download_logo, query_marketing_info,
 };
 
 // version info for migration info
@@ -56,8 +57,9 @@ pub fn execute(
         to successfully complete its execution is the address form config.token_factory_addr */
         ExecuteMsg::Burn { amount } => Ok(try_burn(deps, env, info, amount)?),
         ExecuteMsg::Mint { recipient, amount } => Ok(try_mint(deps, env, info, recipient, amount)?),
+        
         /* Default methods from CW20 Standard with no modifications:
-        https://github.com/CosmWasm/cw-plus/tree/main/packages/cw20 */
+        https://github.com/CosmWasm/cw-plus/tree/main/contracts/cw20-base */
         ExecuteMsg::Transfer { recipient, amount } => {
             Ok(execute_transfer(deps, env, info, recipient, amount)?)
         }
@@ -114,16 +116,19 @@ pub fn execute(
 pub fn try_burn(
     deps: DepsMut,
     env: Env,
-    info: MessageInfo,
+    mut info: MessageInfo,
     amount: Uint128,
 ) -> Result<Response, ContractError> {
     let config = CONFIG.load(deps.storage)?;
     let sender_addr = deps.api.addr_canonicalize(&info.sender.to_string())?;
 
     if config.token_factory_addr != sender_addr {
-        return Err(ContractError::Unauthorized {});
+        return Err(ContractError::UnauthorizedAddr {
+            received: sender_addr,
+            expected: config.token_factory_addr,
+        });
     }
-
+    info.sender = deps.api.addr_validate("human")?;
     Ok(execute_burn(deps, env, info, amount)?)
 }
 
@@ -138,7 +143,10 @@ pub fn try_mint(
     let sender_addr = deps.api.addr_canonicalize(&info.sender.to_string())?;
 
     if config.token_factory_addr != sender_addr {
-        return Err(ContractError::Unauthorized {});
+        return Err(ContractError::UnauthorizedAddr {
+            received: sender_addr,
+            expected: config.token_factory_addr,
+        });
     }
 
     Ok(execute_mint(deps, env, info, recipient, amount)?)
@@ -152,12 +160,23 @@ pub fn query(deps: Deps, _env: Env, msg: QueryMsg) -> StdResult<Binary> {
             to_binary(&config)
         },
         /* Default methods from CW20 Standard with no modifications:
-        https://github.com/CosmWasm/cw-plus/tree/main/packages/cw20 */
-        QueryMsg::TokenInfo {} => to_binary(&query_token_info(deps)?),
+        https://github.com/CosmWasm/cw-plus/tree/main/contracts/cw20-base */
         QueryMsg::Balance { address } => to_binary(&query_balance(deps, address)?),
+        QueryMsg::TokenInfo {} => to_binary(&query_token_info(deps)?),
+        QueryMsg::Minter {} => to_binary(&query_minter(deps)?),
         QueryMsg::Allowance { owner, spender } => {
             to_binary(&query_allowance(deps, owner, spender)?)
         }
+        QueryMsg::AllAllowances {
+            owner,
+            start_after,
+            limit,
+        } => to_binary(&query_all_allowances(deps, owner, start_after, limit)?),
+        QueryMsg::AllAccounts { start_after, limit } => {
+            to_binary(&query_all_accounts(deps, start_after, limit)?)
+        }
+        QueryMsg::MarketingInfo {} => to_binary(&query_marketing_info(deps)?),
+        QueryMsg::DownloadLogo {} => to_binary(&query_download_logo(deps)?),
     }
 }
 
